# Trading game for recruitment events. 

## Installation

`pip install gr-tradinggame`

### Manual game

1. Run the code in `notebooks/example_manual.ipynb` in a notebook (looks best on Colab, with fullscreen cell display). [![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/soerenwolfers/gr_tradinggame/blob/main/notebooks/example_manual.ipynb)

2. Have teams shout / show their decisions and enter them by clicking buttons. 

### Coding game

1. Run the code in `notebooks/example_server.ipynb`. [![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/soerenwolfers/gr_tradinggame/blob/main/notebooks/example_server.ipynb)



2. The output will contain `Serving <id>`. Give that `id` to the teams and have them test and submit their solutions with that `id` as in `notebooks/example_client.ipynb`. [![Open in Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/soerenwolfers/gr_tradinggame/blob/main/notebooks/example_clients.ipynb)

3. Run the remaining cells in your server notebook to see who wins.




